{% extends "admin/base_site.html" %}
{% load i18n admin_static admin_modify %}
{% load url from future %}
{% load admin_urls %}
{% load bootstrap_tags %}

{% block extrahead %}{{ block.super }}

{% url 'admin:jsi18n' as jsi18nurl %}
<script type="text/javascript" src="{{ jsi18nurl|default:"../../../jsi18n/" }}"></script>
{{ media }}
{% endblock %}

{% block extrastyle %}{{ block.super }}
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}chosen/chosen.css">
{% endblock %}

{% block coltype %}{% if ordered_objects %}colMS{% else %}colM{% endif %}{% endblock %}

{% block bodyclass %}change-form{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
<ul class="breadcrumb">
<li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a> <span class="divider">/</span></li>
<li><a href="{% url 'freeplay_dashboard' %}">{% trans 'Manage Content' %}</a> <span class="divider">/</span></li>
{% comment %}<li>{% if has_change_permission %}<a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>{% else %}{{ opts.verbose_name_plural|capfirst }}{% endif %} <span class="divider">/</span></li>{% endcomment %}
<li>{% trans 'Delete' %} {{ original|truncatewords:"18" }}</li>
</ul>
{% endblock %}
{% endif %}

{% block content %}
<div id="content-main" class="span10">
  {% block object-tools %}{% endblock %}
  {% include "admin/freeplay/_item_delete.html" %}
</div>
{% endblock %}
